@@ -1,7 +1,7 @@
 from langchain.prompts.prompt import PromptTemplate
 from steamship.invocable import PackageService, post
 
-from steamship_langchain.llms import SteamshipGPT
+from steamship_langchain.llms import OpenAI
 
 
 class GreetingPackage(PackageService):
@@ -12,5 +12,5 @@ class GreetingPackage(PackageService):
             template="Create a welcome message for user {user}. Thank them for running their LangChain app on Steamship. "
             "Encourage them to deploy their app via `ship deploy` when ready.",
         )
-        llm = SteamshipGPT(client=self.client, temperature=0.8)
+        llm = OpenAI(client=self.client, temperature=0.8)
         return llm(prompt.format(user=user))
