@@ -4,6 +4,7 @@ import logging
 from collections import defaultdict
 from typing import Any, Dict, Generator, List, Mapping, Optional
 
+import tiktoken
 from langchain.llms.base import Generation, LLMResult
 from langchain.llms.openai import BaseOpenAI
 from pydantic import root_validator
@@ -51,11 +52,13 @@ class OpenAI(BaseOpenAI):
         }
 
     def _invocation_params(self, stop: Optional[List[str]] = None):
-        stop_str = ",".join(stop) if stop is not None else ""
+        stop_str = (
+            ",".join(stop) if stop is not None and not isinstance(stop, str) else (stop or "")
+        )
 
         return {
-            **self._default_params,
             "stop": stop_str,
+            **self._default_params,
         }
 
     @property
@@ -125,6 +128,13 @@ class OpenAI(BaseOpenAI):
             generations=generations, llm_output={"token_usage": dict(total_token_usage)}
         )
 
+    def get_num_tokens(self, text: str) -> int:
+        """Calculate num tokens with tiktoken package."""
+        encoder = "p50k_base"
+        enc = tiktoken.get_encoding(encoder)
+        tokenized_text = enc.encode(text)
+        return len(tokenized_text)
+
     def stream(self, prompt: str, stop: Optional[List[str]] = None) -> Generator:
         raise NotImplementedError("Support for streaming is not supported yet.")
 
@@ -151,7 +161,7 @@ class OpenAI(BaseOpenAI):
         blocks = [Block(text=prompt) for prompt in prompts]
 
         generations = []
-        token_usage = None
+        token_usage = {}
         try:
             prompt_file = File.create(client=self.client, blocks=blocks)
             task = llm_plugin.tag(doc=prompt_file)
