@@ -10,4 +10,4 @@ def test_search_tool(client: Steamship):
 
     answer = tool_under_test.search("Who won the 2019 World Series?")
     assert len(answer) != 0
-    assert answer == "Washington Nationals"
+    assert "Washington Nationals" in answer
